@@ -2,13 +2,19 @@
  *  Copyright (C) 1999-2002 Bernd Gehrmann
  *                          bernd@mail.berlios.de
  *
- * This program may be distributed under the terms of the Q Public
- * License as defined by Trolltech AS of Norway and appearing in the
- * file LICENSE.QPL included in the packaging of this file.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
@@ -50,6 +56,7 @@ private slots:
     void comboActivated(int index);
     void backClicked();
     void forwClicked();
+    void saveAsClicked();
 
 private:
     void newDiffHunk(int& linenoA, int& linenoB, const QStringList& linesA,
@@ -69,6 +76,7 @@ private:
     QPtrList<DiffItem> items;
     int markeditem;
     KConfig& partConfig;
+    QStringList m_diffOutput;
 };
 
 #endif
