@@ -38,15 +38,14 @@
 #include <kuser.h>
 #include <kdebug.h>
 
-#include "config.h"
 #include "cvsservice_stub.h"
 #include "progressdlg.h"
 
 // These regular expression parts aren't useful to check the validity of the
 // CVSROOT specification. They are just used to extract the different parts of it.
-static const QString userNameRegExp("([a-z0-9_][a-z0-9_-]*)?");
+static const QString userNameRegExp("([a-z0-9_][a-z0-9_-.]*)?");
 static const QString passwordRegExp("(:[^@]+)?");
-static const QString hostNameRegExp("([^:/]+)");
+static const QString hostNameRegExp("([^:/@]+)");
 static const QString portRegExp("(:(\\d*))?");
 static const QString pathRegExp("(/.*)");
 
