@@ -3,7 +3,7 @@ cat << EOF > $LOCATION_ROOT/${APP_NAME_LC}/${APP_NAME_LC}.cpp
 /*
  * ${APP_NAME_LC}.cpp
  *
- * Copyright (C) 2001  <kurt@granroth.org>
+ * Copyright (C) 2004 $AUTHOR <$EMAIL>
  */
 #include "${APP_NAME_LC}.h"
 #include "${APP_NAME_LC}.moc"
@@ -31,9 +31,6 @@ ${APP_NAME}::${APP_NAME}()
     // then, setup our actions
     setupActions();
 
-    // and a status bar
-    statusBar()->show();
-
     // this routine will find and load our Part.  it finds the Part by
     // name which is a bad idea usually.. but it's alright in this
     // case since our Part is made for this Shell
@@ -87,8 +84,8 @@ void ${APP_NAME}::setupActions()
 
     KStdAction::quit(kapp, SLOT(quit()), actionCollection());
 
-    m_toolbarAction = KStdAction::showToolbar(this, SLOT(optionsShowToolbar()), actionCollection());
-    m_statusbarAction = KStdAction::showStatusbar(this, SLOT(optionsShowStatusbar()), actionCollection());
+    createStandardStatusBarAction();
+    setStandardToolBarMenuEnabled(true);
 
     KStdAction::keyBindings(this, SLOT(optionsConfigureKeys()), actionCollection());
     KStdAction::configureToolbars(this, SLOT(optionsConfigureToolbars()), actionCollection());
@@ -125,30 +122,12 @@ void ${APP_NAME}::fileNew()
     };
 }
 
-
-void ${APP_NAME}::optionsShowToolbar()
-{
-    // this is all very cut and paste code for showing/hiding the
-    // toolbar
-    if (m_toolbarAction->isChecked())
-        toolBar()->show();
-    else
-        toolBar()->hide();
-}
-
-void ${APP_NAME}::optionsShowStatusbar()
-{
-    // this is all very cut and paste code for showing/hiding the
-    // statusbar
-    if (m_statusbarAction->isChecked())
-        statusBar()->show();
-    else
-        statusBar()->hide();
-}
-
 void ${APP_NAME}::optionsConfigureKeys()
 {
-    KKeyDialog::configureKeys(actionCollection(), "${APP_NAME_LC}_shell.rc");
+  KKeyDialog dlg( true,  this );
+  dlg.insert( actionCollection(), "${APP_NAME_LC}_shell.rc" );
+  dlg.insert( m_part->actionCollection(), "${APP_NAME_LC}_part.rc" );
+  (void) dlg.configure( true );
 }
 
 void ${APP_NAME}::optionsConfigureToolbars()
@@ -172,10 +151,10 @@ void ${APP_NAME}::fileOpen()
     // this slot is called whenever the File->Open menu is selected,
     // the Open shortcut is pressed (usually CTRL+O) or the Open toolbar
     // button is clicked
-    QString file_name =
-        KFileDialog::getOpenFileName( QString::null, QString::null, this );
+    KURL url =
+        KFileDialog::getOpenURL( QString::null, QString::null, this );
 
-    if (file_name.isEmpty() == false)
+    if (url.isEmpty() == false)
     {
         // About this function, the style guide (
         // http://developer.kde.org/documentation/standards/kde/style/basics/index.html )
@@ -184,13 +163,13 @@ void ${APP_NAME}::fileOpen()
         if ( m_part->url().isEmpty() && ! m_part->isModified() )
         {
             // we open the file in this window...
-            load( KURL( file_name ) );
+            load( url );
         }
         else
         {
             // we open the file in a new window...
             ${APP_NAME}* newWin = new ${APP_NAME};
-            newWin->load( KURL( file_name ) );
+            newWin->load( url );
             newWin->show();
         }
     }
