@@ -71,7 +71,7 @@ class CatalogManager : public KMainWindow
 {
    Q_OBJECT
 public:
-   CatalogManager(QString configfile = KBABEL_DEFAULTPROJECT);
+   CatalogManager(QString configfile = QString() );
    ~CatalogManager();
 
    KBabel::CatManSettings settings() const;
@@ -204,6 +204,7 @@ private:
    
    /// options used in findNextFile
    KBabel::FindOptions _findOptions;
+
    
    /// project configuration file
    QString _configFile;
