@@ -323,12 +323,10 @@ void CatalogManagerView::pause(bool flag)
    if(flag)
    {
       _updateTimer->stop();
-      if( _dirWatch ) _dirWatch->stopScan();
    }
    else
    {
       _updateTimer->start(10000);
-      if( _dirWatch ) _dirWatch->startScan();
    }
 }
 
@@ -1378,7 +1376,6 @@ QString CatalogManagerView::find( FindOptions &options, QStringList &rest )
 	    }
 	} else kdDebug(KBABEL_CATMAN) << "Skipping " << item->poFile() << endl;
 	emit signalSearchedFile(1);
-	kapp->processEvents(10);
 	if( _stop || _stopSearch ) {
 	    _stopSearch = false;
 	    rest.clear();
@@ -1842,11 +1839,7 @@ void CatalogManagerView::buildTree()
    while ( it.current() && !_stop)
    {
       it.current()->checkUpdate(true);
-
-      kapp->processEvents(10);
-
-      i++;
-
+      ++i;
       ++it;
    }
 
@@ -1856,11 +1849,7 @@ void CatalogManagerView::buildTree()
    while ( dit.current() && !_stop)
    {
       dit.current()->checkUpdate();
-
-      kapp->processEvents(10);
-
-      i++;
-
+      ++i;
       ++dit;
    }
 
@@ -1956,8 +1945,6 @@ bool CatalogManagerView::buildDir(const QString& baseDir,const QString& relDir
 
       for (  it = entryList.constBegin(); it != entryList.constEnd() && !_stop ; ++it )
       {
-          kapp->processEvents(100);
-
 	  if( _stop ) return false;
 
           if((*it)=="." || (*it)=="..")
@@ -2059,8 +2046,6 @@ void CatalogManagerView::updateDir(QString relDir)
 
       for (  it = entryList.constBegin(); it != entryList.constEnd(); ++it )
       {
-          kapp->processEvents(100);
-
           if( _stop ) return;
 
           if((*it)=="." || (*it)=="..")
@@ -2143,8 +2128,6 @@ void CatalogManagerView::updateDir(QString relDir)
 
       for (  it = entryList.constBegin(); it != entryList.constEnd(); ++it )
       {
-          kapp->processEvents(100);
-
           if( _stop ) return;
 
           if((*it)=="." || (*it)=="..")
@@ -2237,7 +2220,6 @@ void CatalogManagerView::updateDir(QString relDir)
 void CatalogManagerView::directoryChanged(const QString& dir)
 {
    pause(true);
-   _dirWatch->stopScan();
 
    QString relDir, relDirPo, relDirPot;
    if(dir.startsWith(_settings.poBaseDir))
@@ -2326,7 +2308,6 @@ void CatalogManagerView::directoryChanged(const QString& dir)
       updateDir(relDir);
    }
 
-   _dirWatch->startScan();
    pause(false);
 }
 
@@ -2334,7 +2315,6 @@ void CatalogManagerView::directoryChanged(const QString& dir)
 void CatalogManagerView::directoryDeleted(const QString& dir)
 {
    pause(true);
-   _dirWatch->stopScan();
 
    QString relDir, relDirPo, relDirPot;
    if(dir.startsWith(_settings.poBaseDir))
@@ -2432,7 +2412,6 @@ void CatalogManagerView::directoryDeleted(const QString& dir)
       }
    }
 
-   _dirWatch->startScan();
    pause(false);
 }
 
