@@ -2,6 +2,7 @@
   This file is part of KBabel
 
   Copyright (C) 2002-2003 by Marco Wegner <mail@marcowegner.de>
+  Copyright (C) 2005, 2006 by Nicolas GOUTTE <goutte@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -71,7 +72,7 @@ class CVSDialog : public KDialog
      * Constructor for creating the dialog.
      * @param cmd The type of command to be executed.
      */
-    CVSDialog( CVS::Command cmd, QWidget * parent = 0, const char * name = 0, bool modal = false, WFlags f = 0 );
+    CVSDialog( CVS::Command cmd, QWidget * parent, KSharedConfig* config );
     ~CVSDialog();
     /**
      * Set the list of files which will be used for the CVS command.
@@ -149,6 +150,9 @@ class CVSDialog : public KDialog
 
     /// Combo box for the encoding
     KComboBox* m_encodingComboBox;
+
+    /// Configuration data (of the KBabel project)
+    KSharedConfig* m_config;
 };
 
 #endif // CVSDIALOG_H
