@@ -17,7 +17,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
@@ -82,7 +82,7 @@ void MultiRoughTransDlg::translate()
 	    if( catalog->openURL( url ) != OK )
 	    {
 		KMessageBox::error(this, i18n("Error while trying to read file:\n %1\n"
-		    "Maybe it is not a valid PO file.").arg(url.url()));
+		    "Maybe it is not a valid PO file.").arg(url.prettyURL()));
 		filesProgressbar->advance(1);
 		continue;
 	    }
@@ -94,7 +94,7 @@ void MultiRoughTransDlg::translate()
 	    if( catalog->openURL( poturl, url ) != OK )
 	    {
 		KMessageBox::error(this, i18n("Error while trying to read file:\n %1\n"
-		    "Maybe it is not a valid PO file.").arg(poturl.url()));
+		    "Maybe it is not a valid PO file.").arg(poturl.prettyURL()));
 		filesProgressbar->advance(1);
 		continue;
 	    }
