@@ -31,6 +31,7 @@
 
 **************************************************************************** */
 
+#include "resources.h"
 #include "kbproject.h"
 #include "kbprojectmanager.h"
 #include "kbprojectsettings.h"
@@ -76,6 +77,11 @@ Project::Project( const QString& file ) :
             // Empty files are allowed too
             kdWarning() << "Empty KBabel project file!" << endl;
         }
+	else if ( mime->name() == "application/octet-stream" )
+        {
+	    // this can happen if the file has some very long lines
+	    kdWarning() << "KBabel project file detected as octet-stream! Perhaps there are very long lines in it!" << endl;
+        }
         else
 	{
             // Unknown mime type, abort!
@@ -86,11 +92,13 @@ Project::Project( const QString& file ) :
     }
         
     _config = KSharedConfig::openConfig (_filename, false, false);
-    kdDebug () << "Opened project " << _filename << endl;
+    kdDebug (KBABEL) << "Opened project " << _filename << endl;
     
     // read the project name
     _config->setGroup( "Project" );
     _name = _config->readEntry( "Name", QString() );
+    if ( _name.isEmpty() )
+	_name = "Default-Project"; // set default project name
 
     // ### FIXME: why is the Version number not written to the project file?
     if ( _config->readEntry( "Version", QString() ) != "1.0.1" )
