@@ -55,7 +55,7 @@ class DiffPreferences;
 
 namespace KBabel {
 
-class ProjectDialog : public KConfigDialog
+class KDE_EXPORT ProjectDialog : public KConfigDialog
 {
     Q_OBJECT
 public:
