@@ -47,7 +47,7 @@
  *
  ***************************************************/
 
-K_EXPORT_COMPONENT_FACTORY( kbabel_accelstool, KGenericFactory<AcceleratorTool> )
+K_EXPORT_COMPONENT_FACTORY( kbabel_accelstool, KGenericFactory<AcceleratorTool> ( "kbabeldatatool" ) )
 
 using namespace KBabel;
 
@@ -122,11 +122,11 @@ bool AcceleratorTool::run( const QString& command, void* data, const QString& da
 	
 	if(hasError)
 	{
-	    item->appendError( "accelerator" );
+	    item->appendError( "Accelerator" );
 	}
 	else
 	{
-	    item->removeError( "accelerator" );
+	    item->removeError( "Accelerator" );
 	}
 			
 	return !hasError;
