@@ -48,7 +48,7 @@
  *
  ***************************************************/
 
-K_EXPORT_COMPONENT_FACTORY( kbabel_equationstool, KGenericFactory<EquationsTool> )
+K_EXPORT_COMPONENT_FACTORY( kbabel_equationstool, KGenericFactory<EquationsTool> ( "kbabeldatatool" ) )
 
 using namespace KBabel;
 
