@@ -16,12 +16,25 @@
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
+
+   In addition, as a special exception, the copyright holders give
+   permission to link the code of this program with any edition of
+   the Qt library by Trolltech AS, Norway (or with modified versions
+   of Qt that use the same license as Qt), and distribute linked
+   combinations including the two.  You must obey the GNU General
+   Public License in all respects for all of the code used other than
+   Qt. If you modify this file, you may extend this exception to
+   your version of the file, but you are not obligated to do so.  If
+   you do not wish to do so, delete this exception statement from
+   your version.
+
 */
 
 #ifndef __main_h__
 #define __main_h__
 
-#include <qregexp.h>
+#include "kbproject.h"
+
 #include <kdatatool.h>
 
 class PluralsTool : public KDataTool
@@ -32,6 +45,7 @@ public:
     PluralsTool( QObject* parent, const char* name, const QStringList & );
     virtual bool run( const QString& command, void* data, const QString& datatype, const QString& mimetype);
 private:
+    KBabel::Project::Ptr _cache_origin;
     QRegExp _plurals;
     int _neededForms;
 };
