@@ -123,13 +123,15 @@ public:
 KBabelMW::KBabelMW(QString projectFile)
         : KDockMainWindow (), m_charselectorview(0)
 {
+    if ( projectFile.isEmpty() )
+    	projectFile = KBabel::ProjectManager::defaultProjectName();
     _project = ProjectManager::open(projectFile);
     
-    if ( _project == NULL )
+    if ( _project == NULL ) // FIXME should not happen anymore
     {
 	KMessageBox::error( this, i18n("Cannot open project file\n%1").arg(projectFile)
             , i18n("Project File Error"));
-	_project = ProjectManager::open(KBABEL_DEFAULTPROJECT);
+	_project = ProjectManager::open(KBabel::ProjectManager::defaultProjectName());
     }
     
     KBCatalog* catalog=new KBCatalog(projectFile);
@@ -139,13 +141,15 @@ KBabelMW::KBabelMW(QString projectFile)
 KBabelMW::KBabelMW(KBCatalog* catalog, QString projectFile)
         : KDockMainWindow (), m_charselectorview(0)
 {
+    if ( projectFile.isEmpty() )
+    	projectFile = KBabel::ProjectManager::defaultProjectName();
     _project = ProjectManager::open(projectFile);
 
     if ( _project == NULL )
     {
 	KMessageBox::error( this, i18n("Cannot open project file\n%1").arg(projectFile)
             , i18n("Project File Error"));
-	_project = ProjectManager::open(KBABEL_DEFAULTPROJECT);
+	_project = ProjectManager::open(KBabel::ProjectManager::defaultProjectName());
     }
     
     init(catalog);
@@ -598,7 +602,7 @@ void KBabelMW::setupActions()
    action = new KAction(i18n("C&lose"), "fileclose"
            , this, SLOT(projectClose()),actionCollection()
            ,"project_close");
-   action->setEnabled (_project->filename() != KBABEL_DEFAULTPROJECT);
+   action->setEnabled (_project->filename() != KBabel::ProjectManager::defaultProjectName() );
 
    action = new KAction(i18n("&Configure..."), "configure"
            , this, SLOT(projectConfigure()),actionCollection()
@@ -1504,7 +1508,7 @@ void KBabelMW::clearStatusbarMsg()
 void KBabelMW::changeCaption(const QString& text)
 {
     // display the text on the caption
-    setCaption(text + ( _project->filename () != KBABEL_DEFAULTPROJECT ?
+    setCaption(text + ( _project->filename () != KBabel::ProjectManager::defaultProjectName() ?
             " (" + _project->name() + ")" : "" /* KDE 3.4: i18n("(No project)")*/ )
         ,m_view->isModified());
 }
@@ -1677,8 +1681,7 @@ void KBabelMW::initBookmarks(QPtrList<KBabelBookmark> list)
 
 void KBabelMW::slotAddBookmark()
 {
-  bmHandler->addBookmark(_currentIndex,
-    m_view->catalog()->msgid(_currentIndex - 1).first());
+    bmHandler->addBookmark(_currentIndex+1, m_view->catalog()->msgid(_currentIndex).first());
 }
 
 void KBabelMW::slotOpenBookmark(int index)
@@ -1703,7 +1706,7 @@ void KBabelMW::projectNew()
 void KBabelMW::projectOpen()
 {
     QString oldproject = m_view->project();
-    if( oldproject == KBABEL_DEFAULTPROJECT )
+    if( oldproject == KBabel::ProjectManager::defaultProjectName() )
     {
         oldproject = QString();
     }
@@ -1731,7 +1734,7 @@ void KBabelMW::projectOpenRecent(const KURL& url)
 void KBabelMW::projectOpen(const QString& file)
 {
     QString oldproject = m_view->project();
-    if( oldproject == KBABEL_DEFAULTPROJECT )
+    if( oldproject == KBabel::ProjectManager::defaultProjectName() )
     {
         oldproject = "";
     }
@@ -1750,22 +1753,23 @@ void KBabelMW::projectOpen(const QString& file)
     {
 	KMessageBox::error( this, i18n("Cannot open project file\n%1").arg(file)
             , i18n("Project File Error"));
-	_project = ProjectManager::open(KBABEL_DEFAULTPROJECT);
+	_project = ProjectManager::open(KBabel::ProjectManager::defaultProjectName());
 	m_view->useProject(_project);
-	changeProjectActions(KBABEL_DEFAULTPROJECT);
+	changeProjectActions(KBabel::ProjectManager::defaultProjectName());
     }
 }
 
 void KBabelMW::projectClose()
 {
-    m_view->useProject( KBabel::ProjectManager::open(KBABEL_DEFAULTPROJECT) );
-    _project = ProjectManager::open(KBABEL_DEFAULTPROJECT);
-    changeProjectActions(KBABEL_DEFAULTPROJECT);
+    QString defaultProject = KBabel::ProjectManager::defaultProjectName();
+    m_view->useProject( KBabel::ProjectManager::open(defaultProject) );
+    _project = ProjectManager::open(defaultProject);
+    changeProjectActions(defaultProject);
 }
 
 void KBabelMW::changeProjectActions(const QString& project)
 {
-    bool def = project == KBABEL_DEFAULTPROJECT;
+    bool def = (project == KBabel::ProjectManager::defaultProjectName());
 
     KAction* saveAction=(KAction*)actionCollection()->action( "project_close" );
     saveAction->setEnabled( ! def );
