@@ -3,7 +3,7 @@
 
   Copyright (C) 1999-2000 by Matthias Kiefer
                             <matthias.kiefer@gmx.de>
-		2002-2004  by Stanislav Visnovsky
+		2002-2005  by Stanislav Visnovsky
 			    <visnovsky@kde.org>
 
   This program is free software; you can redistribute it and/or modify
@@ -18,7 +18,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   In addition, as a special exception, the copyright holders give
   permission to link the code of this program with any edition of
@@ -574,6 +574,12 @@ private:
    */
    bool _findBreakAtEnd;
 
+   /*
+   * flag, if we search backwards and the direction was already
+   * changed (see findNext and findPrev)
+   */   
+   bool _redirectedBackSearch;
+
    bool _showTryLaterBox;
 
    KBabel::DocPosition _replacePos;
