@@ -63,14 +63,39 @@
 using namespace KBabel;
 
 MyMultiLineEdit::MyMultiLineEdit(int ID, QWidget* parent,const char* name)
-                :KTextEdit(parent,name), emitUndo(true), _firstChangedLine(0), 
-		_lastChangedLine(0), _lastParagraph(0), 
-		_lastParagraphOffset(0), _dontUpdate(false), _myID (ID),
+                :KTextEdit(parent,name), emitUndo(true), 
+		_firstChangedLine(0), 
+		_lastChangedLine(0), 
+        	_lastParagraph(0), 
+		_lastParagraphOffset(0), 
+		_lastSelectionStart(-1), 
+		_lastSelectionEnd(-1),
+		_dontUpdate(false), _myID (ID),
 		 _menu(0), _overwrite(false)
 {
    setUndoRedoEnabled(false); // we handle this ourselves
    setWordWrap( WidgetWidth );
    viewport()->setAcceptDrops( false ); // we need our parent to get drops
+
+   connect(this, SIGNAL(selectionChanged()), this, SLOT( onSelectionChanged() ) );
+}
+
+void MyMultiLineEdit::onSelectionChanged()
+{
+    kdDebug(KBABEL) << "MyMultiLineEdit::onSelectionChanged" << endl;
+    int parFrom, parTo, indexFrom, indexTo;
+    if ( hasSelectedText() ) {
+        getSelection( &parFrom, &indexFrom, &parTo, &indexTo );
+        kdDebug(KBABEL) << "parFrom=" << parFrom << "indexFrom=" << indexFrom << "parTo=" << parTo << "indexTo=" << indexTo << endl;
+        _lastSelectionStart = beginOfMarkedText();
+    }
+    else
+    {
+        _lastSelectionStart = -1; // no selection
+        _lastSelectionEnd = -1;
+    }
+
+    //kdDebug(KBABEL) << "_lastSelectionStart=" << _lastSelectionStart << endl;
 }
 
 void MyMultiLineEdit::processCommand(EditCommand* cmd, bool undo)
@@ -145,6 +170,22 @@ void MyMultiLineEdit::processCommand(EditCommand* cmd, bool undo)
    emitCursorPosition();
 }
 
+int MyMultiLineEdit::beginOfLastMarkedText()
+{
+    if ( _lastSelectionStart != -1 )
+        return _lastSelectionStart;
+    else
+        return currentIndex();
+}
+
+int MyMultiLineEdit::endOfLastMarkedText()
+{
+    if ( _lastSelectionEnd != -1 )
+        return _lastSelectionEnd;
+    else
+        return currentIndex();
+}
+
 int MyMultiLineEdit::beginOfMarkedText()
 {
 	int beginX=0;
