@@ -16,8 +16,19 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
+  In addition, as a special exception, the copyright holders give
+  permission to link the code of this program with any edition of
+  the Qt library by Trolltech AS, Norway (or with modified versions
+  of Qt that use the same license as Qt), and distribute linked
+  combinations including the two.  You must obey the GNU General
+  Public License in all respects for all of the code used other than
+  Qt. If you modify this file, you may extend this exception to
+  your version of the file, but you are not obligated to do so.  If
+  you do not wish to do so, delete this exception statement from
+  your version.
+ 
 **************************************************************************** */
 
 
@@ -47,6 +58,9 @@ KBabelDict::KBabelDict()
     // HACK: hide default button, otherwise it would be Help button
     showButtonOK(false);
 
+    // KBabelDict has not a separate help file, so point to the correct part of the KBabel documentation
+    setHelp( "using-kbabeldict", "kbabel" );
+
     setMainWidget(view);
 
     readConfig();
