@@ -14,6 +14,18 @@
   Andrea Rizzi rizzi@kde.org
   
   License GPL v 2.0
+
+ *                                                                         *
+ *   In addition, as a special exception, the copyright holders give       *
+ *   permission to link the code of this program with any edition of       *
+ *   the Qt library by Trolltech AS, Norway (or with modified versions     *
+ *   of Qt that use the same license as Qt), and distribute linked         *
+ *   combinations including the two.  You must obey the GNU General        *
+ *   Public License in all respects for all of the code used other than    *
+ *   Qt. If you modify this file, you may extend this exception to         *
+ *   your version of the file, but you are not obligated to do so.  If     *
+ *   you do not wish to do so, delete this exception statement from        *
+ *   your version.                                                         *
   
 */
 #include "algorithms.h"
@@ -297,7 +309,7 @@ void KDBSearchEngine2::saveSettings(KConfigBase *config)
  uint sourceNumber=0;
  config->writeEntry("NumberOfDBImportSources",sources.count());
  
-   for(QMap<QString,MessagesSource>::iterator sourceIt=sources.begin() ; sourceIt!=sources.end(); sourceIt++)
+   for(QMap<QString,MessagesSource>::iterator sourceIt=sources.begin() ; sourceIt!=sources.end(); ++sourceIt)
     {
      sourceNumber++;
      config->setGroup("DBImportSource-"+QString::number(sourceNumber));
@@ -389,7 +401,7 @@ void KDBSearchEngine2::setSettings()
 	//pw->dbpw->useFilters->setChecked(false);
 	//pw->dbpw->dateToday->setChecked(false);
 	pw->dbpw->sourceList->clear();	
-	for(QMap<QString,MessagesSource>::iterator sourceIt=sources.begin() ; sourceIt!=sources.end(); sourceIt++)
+	for(QMap<QString,MessagesSource>::iterator sourceIt=sources.begin() ; sourceIt!=sources.end(); ++sourceIt)
 	{
 	    pw->dbpw->sourceList->insertItem(sourceIt.key());
 	}
@@ -491,7 +503,7 @@ void  KDBSearchEngine2::scanNowPressed()
     {
 	QValueList<KURL> urls=sources[sourceName].urls();
 	PoScanner ps(di);
-	for(QValueList<KURL>::iterator urlIt=urls.begin();urlIt!=urls.end();urlIt++)
+	for(QValueList<KURL>::iterator urlIt=urls.begin();urlIt!=urls.end();++urlIt)
 	    ps.scanURL(*urlIt);	
 	
     }
@@ -508,10 +520,10 @@ void  KDBSearchEngine2::scanAllPressed()
     PoScanner ps(di);
     
     
-    for(QMap<QString,MessagesSource>::iterator sourceIt=sources.begin() ; sourceIt!=sources.end(); sourceIt++)
+    for(QMap<QString,MessagesSource>::iterator sourceIt=sources.begin() ; sourceIt!=sources.end(); ++sourceIt)
     {
 	QValueList<KURL> urls=(*sourceIt).urls();
-	for(QValueList<KURL>::iterator urlIt=urls.begin();urlIt!=urls.end();urlIt++)
+	for(QValueList<KURL>::iterator urlIt=urls.begin();urlIt!=urls.end();++urlIt)
 	    ps.scanURL(*urlIt);	
     }	
 }
@@ -548,7 +560,7 @@ void  KDBSearchEngine2::editSource()
 
 		KMessageBox::error(0,
 		i18n("The name you chose is already used.\nPlease change the source name."),
-		i18n("Name is not unique"));
+		i18n("Name is Not Unique"));
 		kdDebug(0) << "Name is not uniqe" << endl;
 	    }
 	}while(newName!=sourceName && !nameIsNew);
@@ -600,7 +612,7 @@ void  KDBSearchEngine2::addSource()
 	if(!nameIsNew)
 	{
 		KMessageBox::error(0,i18n("The name you chose is already used.\nPlease change the source name."),
-		i18n("Name is not unique"));
+		i18n("Name is Not Unique"));
 	    kdDebug(0) << "Name is not uniqe" << endl;
 	}
 	else
