@@ -7,11 +7,12 @@
 #include <kdebug.h>
 
 Bug::Bug()
+: m_impl( NULL )
 {
 }
 
-Bug::Bug( BugImpl *impl ) :
-    m_impl( impl )
+Bug::Bug( BugImpl *impl )
+: m_impl( impl )
 {
 }
 
@@ -22,7 +23,7 @@ Bug::Bug( const Bug &other )
 
 Bug Bug::fromNumber( const QString &bugNumber )
 {
-    return new BugImpl( QString::null, Person(), bugNumber, 0, Normal, Person(),
+    return new BugImpl( QString::null, Person(), bugNumber, 0xFFFFFFFF, Normal, Person(),
                         Unconfirmed, Bug::BugMergeList() );
 }
 
@@ -153,6 +154,20 @@ void Bug::setTitle( QString title)
         m_impl->title = title;
 }
 
+uint Bug::age() const
+{
+    if ( !m_impl )
+        return 0;
+
+    return m_impl->age;
+}
+
+void Bug::setAge( uint age )
+{
+    if ( m_impl )
+        m_impl->age = age;
+}
+
 struct Person Bug::submitter() const
 {
     if ( !m_impl )
@@ -169,14 +184,6 @@ QString Bug::number() const
     return m_impl->number;
 }
 
-uint Bug::age() const
-{
-   if ( !m_impl )
-       return 0;
-
-   return m_impl->age;
-}
-
 Bug::Severity Bug::severity() const
 {
     if ( !m_impl )
