@@ -26,13 +26,22 @@ class BugCache
         void invalidateBugDetails( const Bug &bug );
         bool hasBugDetails( const Bug& bug ) const;
 
+        void clear();
+
     private:
+        void init();
+    
         void writePerson( KSimpleConfig *file, const QString &key,
                           const Person &p );
         struct Person readPerson (KSimpleConfig *file, const QString &key );
 
+        QString mId;
+
         KSimpleConfig *m_cachePackages;
         KSimpleConfig *m_cacheBugs;
+
+        QString mCachePackagesFileName;
+        QString mCacheBugsFileName;
 };
 
 #endif
