@@ -1,31 +1,27 @@
 #ifndef __bugdetailsjob_h__
 #define __bugdetailsjob_h__
 
-#include "xmlbugjob.h"
+#include "bugjob.h"
 #include "bug.h"
 #include "bugdetails.h"
 #include "bugdetailspart.h"
 
-#include <qdom.h>
-
-class BugDetailsJob : public XmlBugJob
+class BugDetailsJob : public BugJob
 {
     Q_OBJECT
-public:
+  public:
     BugDetailsJob( BugServer * );
     virtual ~BugDetailsJob();
 
     void start( const Bug &bug );
 
-signals:
+  signals:
     void bugDetailsAvailable( const Bug &bug, const BugDetails &details );
 
-protected:
+  protected:
     virtual void process( const QByteArray &data );
 
-    BugDetails parseDomElement( const QDomElement &element );
-
-private:
+  private:
     Bug m_bug;
 };
 
