@@ -32,6 +32,7 @@ namespace KBugBusterMainWindow
 class CWSearchWidget;
 class CWBugListContainer;
 class CWBugDetailsContainer;
+class CWBugDetails;
 
 /**
  * @author Martijn Klingens
@@ -41,10 +42,15 @@ class CentralWidget : public QWidget
     Q_OBJECT
 
 public:
-    CentralWidget( const QCString& initialPackage, const QCString& initialBug,
+    CentralWidget( const QCString &initialPackage,
+                   const QCString &initalComponent,const QCString& initialBug,
                    QWidget* parent = 0, const char* name = 0 );
     ~CentralWidget();
 
+    void initialize( const QString &initialPackage = QString::null,
+                     const QString &initalComponent = QString::null,
+                     const QString &initialBug = QString::null );
+ 
     void readConfig();
     void writeConfig();
 
@@ -55,6 +61,8 @@ public:
 
     void updatePackage();
 
+    CWBugDetails *bugDetailsWidget();
+
 public slots:
     void slotRetrieveBugList( const QString &package, const QString &component );
     void slotRetrieveBugList( const QString &package );
@@ -64,6 +72,7 @@ public slots:
 
     void updatePackageList( const Package::List &pkgs );
     void updateBugList( const Package &pkg, const QString &component, const Bug::List &bugs );
+    void updateBugList( const QString &label, const Bug::List &bugs );
     void updateBugDetails( const Bug &, const BugDetails & );
 
     void slotReloadPackageList();
@@ -71,6 +80,11 @@ public slots:
     void slotReloadBug();
     void slotExtractAttachments();
 
+    /**
+     * Load the bugs the user reported himself, or for which he is the assigned to person
+     */
+    void slotLoadMyBugs();
+
     void mergeBugs();
     void unmergeBugs();
 
