@@ -58,9 +58,9 @@ void KCppPlugin::makeMimeTypeInfo(const QString& mimetype)
     setAttributes(item, KFileMimeTypeInfo::Averaged);
     item = addItemInfo(group, "Strings", i18n("Strings"), QVariant::Int);
     setAttributes(item, KFileMimeTypeInfo::Averaged);
-    item = addItemInfo(group, "i18n Strings", i18n("i18n strings"), QVariant::Int);
+    item = addItemInfo(group, "i18n Strings", i18n("i18n Strings"), QVariant::Int);
     setAttributes(item, KFileMimeTypeInfo::Averaged);
-    item = addItemInfo(group, "Included Files", i18n("Included files"), QVariant::Int);
+    item = addItemInfo(group, "Included Files", i18n("Included Files"), QVariant::Int);
     setAttributes(item, KFileMimeTypeInfo::Averaged);
 }
 
