@@ -34,7 +34,7 @@ public:
      * @param name              The name of the Actor.
      * @param id                The unique id to assign to this Actor.
      */
-    UMLActor(const QString & name = "", Uml::IDType id = Uml::id_None);
+    explicit UMLActor(const QString & name = "", Uml::IDType id = Uml::id_None);
 
     /**
      * Standard deconstructor.
