@@ -14,7 +14,6 @@
 
 #include "umlcanvasobject.h"
 
-class IDChangeLog;
 
 /**
  * This class contains the non-graphical information required for a UML
@@ -44,10 +43,10 @@ public:
     /**
      * Sets up a Artifact.
      *
-     * @param name              The name of the Concept.
+     * @param Name              The name of the Concept.
      * @param id                The unique id of the Concept.
      */
-    UMLArtifact(const QString & Name = "", Uml::IDType id = Uml::id_None);
+    explicit UMLArtifact(const QString & Name = "", Uml::IDType id = Uml::id_None);
 
     /**
      * Standard deconstructor.
