@@ -5,8 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2003-2006                                                *
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
+ *   copyright (C) 2003-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef ASSOCIATION_H
@@ -16,7 +16,6 @@
 #include "umlnamespace.h"
 #include "umlobject.h"
 
-class UMLDoc;
 class UMLRole;
 
 /**
@@ -158,14 +157,16 @@ public:
     /**
      * Sets the UMLObject playing the given role in the association.
      *
-     * @param obj               Pointer to the UMLObject of the given role.
+     * @param obj  Pointer to the UMLObject of the given role.
+     * @param role The Uml::Role_Type played by the association
      */
     void setObject(UMLObject *obj, Uml::Role_Type role);
 
     /**
      * Sets the visibility of the given role of the UMLAssociation.
      *
-     * @param value     Visibility of role A visibility.
+     * @param value  Visibility of role.
+     * @param role   The Uml::Role_Type to which the visibility is being applied 
      */
     void setVisibility(Uml::Visibility value, Uml::Role_Type role);
 
@@ -173,27 +174,31 @@ public:
      * Sets the changeability of the given role of the UMLAssociation.
      *
      * @param value     Changeability_Type of the given role.
+     * @param role      The Uml::Role_Type to which the changeability is being set
      */
     void setChangeability(Uml::Changeability_Type value, Uml::Role_Type role);
 
     /**
      * Sets the multiplicity of the given role of the UMLAssociation.
      *
-     * @param multiA    The multiplicity of the given role.
+     * @param multi    The multiplicity of the given role.
+     * @param role     The Uml::Role_Type to which the multiplicity is being applied
      */
     void setMulti(const QString &multi, Uml::Role_Type role);
 
     /**
      * Sets the name of the given role of the UMLAssociation.
      *
-     * @param roleNameA The name of the given role.
+     * @param roleName  The name to set for the given role.
+     * @param role      The Uml::Role_Type for which to set the name.
      */
     void setRoleName(const QString &roleName, Uml::Role_Type role);
 
     /**
      * Sets the documentation on the given role in the association.
      *
-     * @param doc               The string with the documentation.
+     * @param doc      The string with the documentation.
+     * @param role     The Uml::Role_Type to which the documentation is being applied         
      */
     void setRoleDoc(const QString &doc, Uml::Role_Type role);
 
@@ -214,7 +219,7 @@ public:
     /**
      * Set backward compatibility flag for loading version 1.3.x files.
      * This flag is necessary because the handling of the isNavigable
-     * attribute of <AssociationEnd> was incorrect.
+     * attribute of <UML:AssociationEnd> was incorrect.
      */
     void setOldLoadMode(bool value = true);
 
