@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2002-2004
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,11 +5,20 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2002-2007                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
+
+// own header
+#include "assocrules.h"
+
+// qt/kde includes
 #include <kdebug.h>
 #include <typeinfo>
 
-#include "assocrules.h"
+// local includes
+#include "uml.h"
+#include "umlview.h"
 #include "umlwidget.h"
 #include "umlobject.h"
 #include "associationwidgetlist.h"
@@ -23,6 +27,7 @@
 #include "activitywidget.h"
 #include "forkjoinwidget.h"
 
+
 using namespace Uml;
 
 AssocRules::AssocRules() {}
@@ -35,7 +40,7 @@ bool allowAssociation( Association_Type/* assocType*/, const std::type_info/* &t
 
 }
 
-bool AssocRules::allowAssociation( Association_Type assocType, UMLWidget * widget ) {
+bool AssocRules::allowAssociation( Uml::Association_Type assocType, UMLWidget * widget ) {
     Widget_Type widgetType = widget -> getBaseType();
     bool bValid = false;
     for (int i = 0; i < m_nNumRules; i++) {
@@ -47,7 +52,13 @@ bool AssocRules::allowAssociation( Association_Type assocType, UMLWidget * widge
         }
     }
     if( !bValid ) {
-        return false;
+        // Special case: Subsystem realizes interface in component diagram
+        UMLView *view = UMLApp::app()->getCurrentView();
+        if (view && view->getType() == dt_Component && widgetType == wt_Package &&
+            (assocType == at_Generalization || assocType == at_Realization))
+            bValid = true;
+        else
+            return false;
     }
     AssociationWidgetList list = widget -> getAssocList();
     AssociationWidgetListIt it( list );
@@ -96,7 +107,7 @@ bool AssocRules::allowAssociation( Association_Type assocType, UMLWidget * widge
         return true;
         break;
     default:
-        kdWarning() << "allowAssociation() on unknown type" << endl;
+        kWarning() << "allowAssociation() on unknown type" << endl;
         break;
     }
     return false;
@@ -104,7 +115,7 @@ bool AssocRules::allowAssociation( Association_Type assocType, UMLWidget * widge
 
 // when we know what we are going to connect both ends of the association to, we can
 // use this method.
-bool AssocRules::allowAssociation( Association_Type assocType,
+bool AssocRules::allowAssociation( Uml::Association_Type assocType,
                                    UMLWidget * widgetA, UMLWidget * widgetB,
                                    bool extendedCheck ) {
     Widget_Type widgetTypeA = widgetA->getBaseType();
@@ -192,11 +203,11 @@ bool AssocRules::allowAssociation( Association_Type assocType,
             // no transitions to initial activity allowed
             if (actB && actB->getActivityType() == ActivityWidget::Initial)
                 return false;
-            // Fork_DEPRECATED here means "not applicable".
-            ActivityWidget::ActivityType actTypeA = ActivityWidget::Fork_DEPRECATED;
+            // actType -1 here means "not applicable".
+            int actTypeA = -1;
             if (actA)
                 actTypeA = actA->getActivityType();
-            ActivityWidget::ActivityType actTypeB = ActivityWidget::Fork_DEPRECATED;
+            int actTypeB = -1;
             if (actB)
                 actTypeB = actB->getActivityType();
             // only from a normal, branch or fork activity to the end
@@ -224,20 +235,20 @@ bool AssocRules::allowAssociation( Association_Type assocType,
         break;
 
     default:
-        kdWarning() << "allowAssociation() on unknown type" << endl;
+        kWarning() << "allowAssociation() on unknown type" << endl;
         break;
     }
     return false;
 }
 
-bool AssocRules::allowRole( Association_Type assocType ) {
+bool AssocRules::allowRole( Uml::Association_Type assocType ) {
     for( int i = 0; i < m_nNumRules; i++ )
         if( assocType == m_AssocRules[ i ].assoc_type )
             return m_AssocRules[ i ].role;
     return false;
 }
 
-bool AssocRules::allowMultiplicity( Association_Type assocType, Widget_Type widgetType ) {
+bool AssocRules::allowMultiplicity( Uml::Association_Type assocType, Uml::Widget_Type widgetType ) {
     for( int i = 0; i < m_nNumRules; i++ )
         if( assocType == m_AssocRules[ i ].assoc_type )
             if( widgetType == m_AssocRules[ i ].widgetA_type || widgetType == m_AssocRules[ i ].widgetB_type )
@@ -245,7 +256,7 @@ bool AssocRules::allowMultiplicity( Association_Type assocType, Widget_Type widg
     return false;
 }
 
-bool AssocRules::allowSelf( Association_Type assocType, Widget_Type widgetType ) {
+bool AssocRules::allowSelf( Uml::Association_Type assocType, Uml::Widget_Type widgetType ) {
     for( int i = 0; i < m_nNumRules; i++ )
         if( assocType == m_AssocRules[ i ].assoc_type )
             if( widgetType == m_AssocRules[ i ].widgetA_type || widgetType == m_AssocRules[ i ].widgetB_type )
@@ -254,7 +265,7 @@ bool AssocRules::allowSelf( Association_Type assocType, Widget_Type widgetType )
     return false;
 }
 
-Association_Type AssocRules::isGeneralisationOrRealisation(UMLWidget* widgetA, UMLWidget* widgetB) {
+Uml::Association_Type AssocRules::isGeneralisationOrRealisation(UMLWidget* widgetA, UMLWidget* widgetB) {
     Widget_Type widgetTypeA = widgetA->getBaseType();
     Widget_Type widgetTypeB = widgetB->getBaseType();
     for (int i = 0; i < m_nNumRules; i++) {
@@ -268,7 +279,8 @@ Association_Type AssocRules::isGeneralisationOrRealisation(UMLWidget* widgetA, U
 }
 
 AssocRules::Assoc_Rule AssocRules::m_AssocRules []= {
-    //  Association     widgetA         widgetB         role    multiplicity    directional     self
+    //  Association     widgetA         widgetB         role    multi   directional  self
+    //---------------+----------------+----------------+-------+-------+-------+---------
     { at_Association_Self,wt_Class,     wt_Class,       true,   true,   true,   true  },
     { at_Association_Self,wt_Object,    wt_Object,      true,   true,   true,   true  },
     { at_Association_Self,wt_Interface, wt_Interface,   true,   true,   true,   true  },
@@ -303,6 +315,7 @@ AssocRules::Assoc_Rule AssocRules::m_AssocRules []= {
     { at_Generalization,wt_Interface,   wt_Interface,   false,  false,  false,  false },
     { at_Generalization,wt_UseCase,     wt_UseCase,     false,  false,  false,  false },
     { at_Generalization,wt_Actor,       wt_Actor,       false,  false,  false,  false },
+    { at_Generalization,wt_Component,   wt_Interface,   false,  false,  false,  false },
     { at_Aggregation,   wt_Class,       wt_Class,       true,   true,   false,  true  },
     { at_Aggregation,   wt_Class,       wt_Interface,   true,   true,   false,  false },
     { at_Aggregation,   wt_Class,       wt_Enum,        true,   true,   false,  false },
@@ -328,6 +341,8 @@ AssocRules::Assoc_Rule AssocRules::m_AssocRules []= {
     { at_Realization,   wt_Class,       wt_Interface,   false,  false,  false,  false },
     { at_Realization,   wt_Interface,   wt_Package,     false,  false,  false,  false },
     { at_Realization,   wt_Interface,   wt_Interface,   false,  false,  false,  false },
+    { at_Realization,   wt_Component,   wt_Interface,   false,  false,  false,  false },
+    { at_Realization,   wt_Package,     wt_Interface,   false,  false,  false,  false },
     { at_Composition,   wt_Class,       wt_Class,       true,   true,   false,  true  },
     { at_Composition,   wt_Class,       wt_Interface,   true,   true,   false,  false },
     { at_Composition,   wt_Class,       wt_Enum,        true,   true,   false,  false },
@@ -364,7 +379,7 @@ AssocRules::Assoc_Rule AssocRules::m_AssocRules []= {
     { at_Anchor,        wt_Message,     wt_Note,        false,  false,  false,  false },
     { at_Anchor,        wt_State,       wt_Note,        false,  false,  false,  false },
     { at_Anchor,        wt_Activity,    wt_Note,        false,  false,  false,  false },
-    { at_Relationship,  wt_Entity,      wt_Entity,      true,   false,  true,   false },
+    { at_Relationship,  wt_Entity,      wt_Entity,      true,   true,   true,   true  },
 };
 
 int AssocRules::m_nNumRules = sizeof( m_AssocRules ) / sizeof( AssocRules::Assoc_Rule );
