@@ -26,22 +26,18 @@
 UMLAttribute::UMLAttribute( const UMLObject *parent,
                             const QString& name, Uml::IDType id,
                             Uml::Visibility s,
-                            const QString& type, const QString& iv )
+                            UMLObject *type, const QString& iv )
         : UMLClassifierListItem(parent, name, id) {
     m_InitialValue = iv;
     m_BaseType = Uml::ot_Attribute;
     m_Vis = s;
     m_ParmKind = Uml::pd_In;
-    if (!type.isEmpty()) {
-        UMLDoc *pDoc = UMLApp::app()->getDocument();
-        m_pSecondary = pDoc->findUMLObject(type);
-        if (m_pSecondary == NULL) {
-            if (type.contains( QRegExp("[\\*\\&]") ))
-                m_pSecondary = Object_Factory::createUMLObject(Uml::ot_Datatype, type);
-            else
-                m_pSecondary = Object_Factory::createUMLObject(Uml::ot_Class, type);
-        }
+    /* CHECK: Do we need this:
+    if (type == NULL) {
+        type = Object_Factory::createUMLObject(Uml::ot_Datatype, "undef");
     }
+     */
+    m_pSecondary = type;
 }
 
 UMLAttribute::UMLAttribute(const UMLObject *parent) : UMLClassifierListItem(parent) {
@@ -52,6 +48,18 @@ UMLAttribute::UMLAttribute(const UMLObject *parent) : UMLClassifierListItem(pare
 
 UMLAttribute::~UMLAttribute() { }
 
+void UMLAttribute::setName(const QString &name) {
+    m_Name = name;
+    emit attributeChanged();
+    UMLObject::emitModified();
+}
+
+void UMLAttribute::setVisibility(Uml::Visibility s) {
+    m_Vis = s;
+    emit attributeChanged();
+    UMLObject::emitModified();
+}
+
 QString UMLAttribute::getInitialValue() {
     return m_InitialValue;
 }
@@ -118,7 +126,7 @@ QString UMLAttribute::toString(Uml::Signature_Type sig) {
     return s + getName();
 }
 
-QString UMLAttribute::getFullyQualifiedName(QString separator,
+QString UMLAttribute::getFullyQualifiedName( const QString& separator,
                                             bool includeRoot /* = false */) const {
     UMLOperation *op = NULL;
     UMLObject *owningObject = static_cast<UMLObject*>(parent());
@@ -133,12 +141,13 @@ QString UMLAttribute::getFullyQualifiedName(QString separator,
         << " is not a UMLClassifier" << endl;
         return "";
     }
-    if (separator.isEmpty())
-        separator = UMLApp::app()->activeLanguageScopeSeparator();
-    QString fqn = ownParent->getFullyQualifiedName(separator, includeRoot);
+    QString tempSeparator = separator;
+    if (tempSeparator.isEmpty())
+        tempSeparator = UMLApp::app()->activeLanguageScopeSeparator();
+    QString fqn = ownParent->getFullyQualifiedName(tempSeparator, includeRoot);
     if (op)
-        fqn.append(separator + op->getName());
-    fqn.append(separator + m_Name);
+        fqn.append(tempSeparator + op->getName());
+    fqn.append(tempSeparator + m_Name);
     return fqn;
 }
 
@@ -246,7 +255,7 @@ bool UMLAttribute::showPropertiesDialog(QWidget* parent) {
 }
 
 
-void UMLAttribute::setTemplateParams(QString templateParam, UMLClassifierList &templateParamList) {
+void UMLAttribute::setTemplateParams(const QString& templateParam, UMLClassifierList &templateParamList) {
     if (templateParam.isEmpty())
         return;
     QString type = templateParam.simplifyWhiteSpace();
@@ -299,8 +308,9 @@ UMLClassifierList UMLAttribute::getTemplateParams() {
     UMLClassifierList templateParamList;
     QString type = getType()->getName();
     QString templateParam;
-    //template and generic only in C++ and Java ?
-    if (UMLApp::app()->getActiveLanguage() == Uml::pl_Cpp || UMLApp::app()->getActiveLanguage() == Uml::pl_Java) {
+    // Handle C++/D/Java template/generic parameters
+    const Uml::Programming_Language pl = UMLApp::app()->getActiveLanguage();
+    if (pl == Uml::pl_Cpp || pl == Uml::pl_Java || pl == Uml::pl_D) {
         int start = type.find(QChar('<'));
         if (start >= 0 ) {
             int end = type.findRev(QChar('>'));
@@ -314,4 +324,4 @@ UMLClassifierList UMLAttribute::getTemplateParams() {
 }
 
 
-
+#include "attribute.moc"
