@@ -395,7 +395,7 @@ const QStringList reservedCppKeywords() {
     return keywords;
 }
 
-void createCppStereotypes(){
+void createCppStereotypes() {
     UMLDoc *umldoc = UMLApp::app()->getDocument();
     umldoc->findOrCreateStereotype("constructor");
     // declares an operation as friend
@@ -404,5 +404,10 @@ void createCppStereotypes(){
     umldoc->findOrCreateStereotype("virtual");
 }
 
+QString capitalizeFirstLetter(const QString &string) {
+    QChar firstChar = string.at(0);
+    return firstChar.upper() + string.mid(1);
+}
+
 }  // end namespace Codegen_Utils
 
