@@ -20,6 +20,7 @@
 
 #include "simplecodegenerator.h"
 #include "../umloperationlist.h"
+#include "../umlassociationlist.h"
 
 /**
   * class JSWriter is a JavaScript code generator for UMLClassifier objects
@@ -29,7 +30,7 @@ class JSWriter : public SimpleCodeGenerator {
     Q_OBJECT
 public:
 
-    JSWriter( UMLDoc * parent, const char* name = 0 );
+    JSWriter();
     virtual ~JSWriter();
 
     /**
@@ -38,17 +39,10 @@ public:
       */
     virtual void writeClass(UMLClassifier *c);
 
-    /**
-     * checks whether type is "JSWriter"
-     *
-     * @param type
-     */
-    virtual bool isType (QString & type);
-
     /**
      * returns "JavaScript"
      */
-    virtual QString getLanguage();
+    virtual Uml::Programming_Language getLanguage();
 
     /**
      * get list of reserved keywords
@@ -69,8 +63,16 @@ private:
       * @param opList the list of operations
       * @param js output stream for the JS file
       */
-    void writeOperations(QString classname, UMLOperationList *opList,
-                         QTextStream &js);
+    void writeOperations(QString classname, UMLOperationList *opList, QTextStream &js);
+
+    /**
+     * write a list of associations
+     *
+     * @param classname the name of the class
+     * @param assocList the list of associations
+     * @param as output stream for the AS file
+     */
+    void writeAssociation(QString& classname, UMLAssociationList& assoclist , QTextStream &js);
 };
 
 #endif //JSWRITER
