@@ -13,6 +13,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2006-2007                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 
@@ -20,6 +22,7 @@
 #define RUBYCLASSIFIERCODEDOCUMENT_H
 
 #include <qstring.h>
+
 #include "../codeclassfieldlist.h"
 #include "../classifiercodedocument.h"
 #include "../classifier.h"
@@ -62,7 +65,6 @@ public:
     //CodeDocumentDialog getDialog ( );
 
     QString scopeToRubyDecl(Uml::Visibility scope);
-    QString capitalizeFirstLetter(const QString &string);
 
     // Make it easier on ourselves
     RubyCodeGenerationPolicy * getRubyPolicy();
@@ -82,7 +84,7 @@ protected:
     void resetTextBlocks();
 
     /**
-      * need to overwrite this for ruby since we need to pick up the 
+      * need to overwrite this for ruby since we need to pick up the
     * ruby class declaration block.
       */
     virtual void loadChildTextBlocksFromNode ( QDomElement & root);
@@ -114,9 +116,6 @@ private:
     HierarchicalCodeBlock * protOperationsBlock;
 
     ClassifierInfo * info;
-    QString fileName; // Just for our convience in creating code
-    QString endLine; // characters for ending line. Just for our convience in creating code
-    QString RubyClassName;
 
     void init ( );
     RubyClassDeclarationBlock * getClassDecl();
