@@ -13,18 +13,21 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006                                                    *
+ *   copyright (C) 2006-2007                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
+// own header
+#include "rubycodegenerator.h"
+
+// qt/kde includes
+#include <qregexp.h>
 #include <kconfig.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 
-#include <qregexp.h>
-
-#include "rubycodegenerator.h"
+// local includes
 #include "rubycodecomment.h"
 #include "codeviewerdialog.h"
 #include "../uml.h"
@@ -33,14 +36,12 @@
 //
 
 RubyCodeGenerator::RubyCodeGenerator (QDomElement & elem )
+  : CodeGenerator(elem)
 {
-    initFields();
-    loadFromXMI(elem);
 }
 
 RubyCodeGenerator::RubyCodeGenerator ()
 {
-    initFields();
 }
 
 RubyCodeGenerator::~RubyCodeGenerator ( ) { }
@@ -87,14 +88,6 @@ QString RubyCodeGenerator::getListFieldClassName () {
 // Other methods
 //
 
-QString RubyCodeGenerator::capitalizeFirstLetter(const QString &string)
-{
-    // we could lowercase everything tostart and then capitalize? Nah, it would
-    // screw up formatting like getMyRadicalVariable() to getMyradicalvariable(). Bah.
-    QChar firstChar = string.at(0);
-    return firstChar.upper() + string.mid(1);
-}
-
 QString RubyCodeGenerator::cppToRubyType(const QString &typeStr) {
     QString type = cleanName(typeStr);
     type.replace("const ", "");
@@ -131,13 +124,13 @@ CodeDocument * RubyCodeGenerator::newClassifierCodeDocument ( UMLClassifier * c)
     return doc;
 }
 
+/* These initializations are done in CodeGenFactory::createObject()
 void RubyCodeGenerator::initFields() {
-
     UMLApp::app()->setPolicyExt ( new RubyCodeGenerationPolicy(UMLApp::app()->getConfig()) );
-
     // load Classifier documents from parent document
-    //initFromParentDocument();
+    initFromParentDocument();
 }
+ */
 
 const QStringList RubyCodeGenerator::reservedKeywords() const {
 
