@@ -4,7 +4,7 @@
     begin                : Sat Dec 21 2002
     copyright            : Vincent Decorges
     email                : vincent.decorges@eivd.ch
-      (C) 2003-2006  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
+      (C) 2003-2006  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>
  ***************************************************************************/
 
 /***************************************************************************
@@ -41,7 +41,7 @@ RubyWriter::~RubyWriter() {}
 
 void RubyWriter::writeClass(UMLClassifier *c) {
     if(!c) {
-        kdDebug()<<"Cannot write class of NULL concept!" << endl;
+        kDebug()<<"Cannot write class of NULL concept!" << endl;
         return;
     }
 
@@ -66,7 +66,7 @@ void RubyWriter::writeClass(UMLClassifier *c) {
     QTextStream h(&fileh);
 
     // preparations
-    classifierInfo = new ClassifierInfo(c, m_doc);
+    classifierInfo = new ClassifierInfo(c);
     classifierInfo->fileName = fileName;
     classifierInfo->className = cleanName(c->getName());
 
@@ -101,7 +101,7 @@ void RubyWriter::writeClass(UMLClassifier *c) {
     UMLClassifier *concept;
 
     h<< "class " << cppToRubyType(classname) << (superclasses.count() > 0 ? " < ":"");
-    
+
     int i = 0;
     for (concept = superclasses.first(); concept; concept = superclasses.next()) {
         if (i == 0) {
@@ -144,28 +144,28 @@ void RubyWriter::writeClass(UMLClassifier *c) {
 ////////////////////////////////////////////////////////////////////////////////////
 //  Helper Methods
 
-QString RubyWriter::cppToRubyType(QString typeStr) {
-    typeStr = cleanName(typeStr);
-    typeStr.replace("const ", "");
-    typeStr.replace(QRegExp("[*&\\s]"), "");
-    typeStr.replace(QRegExp("[<>]"), "_");
-    typeStr.replace("QStringList", "Array");
-    typeStr.replace("QString", "String");
-    typeStr.replace("bool", "true|false");
-    typeStr.replace(QRegExp("^(uint|int|ushort|short|ulong|long)$"), "Integer");
-    typeStr.replace(QRegExp("^(float|double)$"), "Float");
-    typeStr.replace(QRegExp("^Q(?=[A-Z])"), "Qt::");
-    typeStr.replace(QRegExp("^K(?!(DE|Parts|IO)"), "KDE::");
+QString RubyWriter::cppToRubyType(const QString &typeStr) {
+    QString type = cleanName(typeStr);
+    type.replace("const ", "");
+    type.replace(QRegExp("[*&\\s]"), "");
+    type.replace(QRegExp("[<>]"), "_");
+    type.replace("QStringList", "Array");
+    type.replace("QString", "String");
+    type.replace("bool", "true|false");
+    type.replace(QRegExp("^(uint|int|ushort|short|ulong|long)$"), "Integer");
+    type.replace(QRegExp("^(float|double)$"), "Float");
+    type.replace(QRegExp("^Q(?=[A-Z])"), "Qt::");
+    type.replace(QRegExp("^K(?!(DE|Parts|IO)"), "KDE::");
 
-    return typeStr;
+    return type;
 }
 
-QString RubyWriter::cppToRubyName(QString nameStr) {
-    nameStr = cleanName(nameStr);
-    nameStr.replace(QRegExp("^m_"), "");
-    nameStr.replace(QRegExp("^[pbn](?=[A-Z])"), "");
-    nameStr = nameStr.mid(0, 1).lower() + nameStr.mid(1);
-    return nameStr;
+QString RubyWriter::cppToRubyName(const QString &nameStr) {
+    QString name = cleanName(nameStr);
+    name.replace(QRegExp("^m_"), "");
+    name.replace(QRegExp("^[pbn](?=[A-Z])"), "");
+    name = name.mid(0, 1).lower() + name.mid(1);
+    return name;
 }
 
 void RubyWriter::writeOperations(UMLClassifier *c,QTextStream &h) {
@@ -212,11 +212,10 @@ void RubyWriter::writeOperations(UMLClassifier *c,QTextStream &h) {
 
 }
 
-void RubyWriter::writeOperations(QString classname, UMLOperationList &opList,
-                                   Uml::Visibility permitScope, QTextStream &h) 
+void RubyWriter::writeOperations(const QString &classname, UMLOperationList &opList,
+                                 Uml::Visibility permitScope, QTextStream &h)
 {
     UMLOperation *op;
-    UMLAttributeList *atl;
     UMLAttribute *at;
 
     switch (permitScope) {
@@ -239,11 +238,11 @@ void RubyWriter::writeOperations(QString classname, UMLOperationList &opList,
 
         // Skip destructors, and operator methods which
         // can't be defined in ruby
-        if (    methodName.startsWith("~") 
+        if (    methodName.startsWith("~")
                 || methodName == "operator ="
                 || methodName == "operator --"
                 || methodName == "operator ++"
-                || methodName == "operator !=" ) 
+                || methodName == "operator !=" )
         {
             continue;
         }
@@ -255,13 +254,13 @@ void RubyWriter::writeOperations(QString classname, UMLOperationList &opList,
         methodName.replace("operator ", "");
         methodName = methodName.mid(0, 1).lower() + methodName.mid(1);
 
-        atl = op -> getParmList();
+        UMLAttributeList atl = op->getParmList();
         //write method doc if we have doc || if at least one of the params has doc
         bool writeDoc = forceDoc() || !op->getDoc().isEmpty();
-        // Always write out the docs for ruby as the type of the 
+        // Always write out the docs for ruby as the type of the
         // arguments and return value of the methods is useful
         writeDoc = true;
-//        for (at = atl->first(); at ; at = atl -> next())
+//        for (at = atl.first(); at; at = atl.next())
 //            writeDoc |= !at->getDoc().isEmpty();
 
         if (writeDoc) {
@@ -276,8 +275,8 @@ void RubyWriter::writeOperations(QString classname, UMLOperationList &opList,
             QRegExp re_params("@param (\\w)(\\w*)");
             int pos = re_params.search(docStr);
             while (pos != -1) {
-                docStr.replace( re_params.cap(0), 
-                                QString("@param _") + re_params.cap(1).lower() + re_params.cap(2) + "_" );
+                docStr.replace( re_params.cap(0),
+                                QString("@param _") + re_params.cap(1).lower() + re_params.cap(2) + '_' );
                 commentedParams.append(re_params.cap(1).lower() + re_params.cap(2));
 
                 pos += re_params.matchedLength() + 3;
@@ -287,15 +286,15 @@ void RubyWriter::writeOperations(QString classname, UMLOperationList &opList,
             docStr.replace("\n", QString("\n") + m_indentation + "# ");
 
             // Write parameter documentation
-            for (at = atl->first(); at ; at = atl->next()) {
+            for (at = atl.first(); at ; at = atl.next()) {
                 // Only write an individual @param entry if one hasn't been found already
                 // in the main doc comment
                 if (commentedParams.contains(cppToRubyName(at->getName())) == 0) {
-                    docStr += (m_endl + m_indentation + "# @param _" + cppToRubyName(at->getName()) + "_");
+                    docStr += (m_endl + m_indentation + "# @param _" + cppToRubyName(at->getName()) + '_');
                     if (at->getDoc().isEmpty()) {
-                        docStr += (" " + cppToRubyType(at->getTypeName()));
+                        docStr += (' ' + cppToRubyType(at->getTypeName()));
                     } else {
-                        docStr += (" " + at->getDoc().replace(QRegExp("[\\n\\r]+[\\t ]*"), m_endl + "   "));
+                        docStr += (' ' + at->getDoc().replace(QRegExp("[\\n\\r]+[\\t ]*"), m_endl + "   "));
                     }
                 }
             }
@@ -329,7 +328,7 @@ void RubyWriter::writeOperations(QString classname, UMLOperationList &opList,
         h<< m_indentation << "def " + methodName << "(";
 
         int j=0;
-        for( at = atl->first(); at ;at = atl->next(),j++) {
+        for (at = atl.first(); at; at = atl.next(), j++) {
             QString nameStr = cppToRubyName(at->getName());
             if (j > 0) {
                 h << ", " << nameStr;
@@ -370,9 +369,12 @@ void RubyWriter::writeAttributeMethods(UMLAttributeList *attribs,
 
 }
 
-void RubyWriter::writeSingleAttributeAccessorMethods(QString fieldName, QString description,
+void RubyWriter::writeSingleAttributeAccessorMethods(
+        const QString &fieldName,
+        const QString &descr,
         QTextStream &h)
 {
+    QString description = descr;
     description.replace(QRegExp("m_[npb](?=[A-Z])"), "");
     description.replace("m_", "");
     description.replace("\n", QString("\n") + m_indentation + "# ");
