@@ -1,6 +1,6 @@
 /***************************************************************************
     copyright            : (C) 2003 Brian Thomas brian.thomas@gsfc.nasa.gov
-      (C) 2004-2006  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
+      (C) 2004-2006  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>
 ***************************************************************************/
 
 /***************************************************************************
@@ -53,7 +53,7 @@ void XMLSchemaWriter::writeClass(UMLClassifier *c)
 {
 
     if (!c) {
-        kdDebug()<<"Cannot write class of NULL classifier!\n";
+        kDebug()<<"Cannot write class of NULL classifier!\n";
         return;
     }
 
@@ -109,9 +109,9 @@ void XMLSchemaWriter::writeClass(UMLClassifier *c)
     // the correct import statements. Leave that for later at this time.
     /*
     //only import classes in a different package as this class
-    UMLClassifierList imports;
+    UMLPackageList imports;
     findObjectsRelated(c,imports);
-    for(UMLClassifier *con = imports.first(); con ; con = imports.next())
+    for(UMLPackage *con = imports.first(); con ; con = imports.next())
         if(con->getPackage() != c->getPackage())
                 XMLschema<<"import "<<con->getPackage()<<"."<<cleanName(con->getName())<<";"<<m_endl;
     */
@@ -734,12 +734,11 @@ void XMLSchemaWriter::writeAssociationRoleDecl( UMLClassifier *c, const QString
 // IF the type is "string" we need to declare it as
 // the XMLSchema Object "String" (there is no string primative in XMLSchema).
 // Same thing again for "bool" to "boolean"
-QString XMLSchemaWriter::fixTypeName(QString string)
+QString XMLSchemaWriter::fixTypeName(const QString& string)
 {
     //  string.replace(QRegExp("^string$"),schemaNamespaceTag+":string");
     //  string.replace(QRegExp("^bool$"),schemaNamespaceTag+":boolean");
-    string.prepend(schemaNamespaceTag+":");
-    return string;
+    return schemaNamespaceTag + ':' + string;
 }
 
 QString XMLSchemaWriter::fixInitialStringDeclValue(QString value, const QString &type)
@@ -772,12 +771,12 @@ QString XMLSchemaWriter::getElementGroupTypeName(UMLClassifier *c)
 }
 
 QString XMLSchemaWriter::makePackageTag (QString tagName) {
-    tagName.prepend( packageNamespaceTag + ":");
+    tagName.prepend( packageNamespaceTag + ':');
     return tagName;
 }
 
 QString XMLSchemaWriter::makeSchemaTag (QString tagName) {
-    tagName.prepend( schemaNamespaceTag + ":");
+    tagName.prepend( schemaNamespaceTag + ':');
     return tagName;
 }
 
