@@ -6,7 +6,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *  copyright (C) 2006                                                     *
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
+ *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
 // own header
@@ -63,7 +63,7 @@ bool PythonImport::preprocess(QString& line) {
     int leadingWhite = line.left(pos).contains( QRegExp("\\s") );
     if (leadingWhite > m_srcIndent[m_srcIndentIndex]) {
         if (m_srcIndex == 0) {
-            kdError() << "PythonImport::preprocess(): internal error 1" << endl;
+            kError() << "PythonImport::preprocess(): internal error 1" << endl;
             return true;
         }
         if (m_braceWasOpened) {
@@ -90,7 +90,7 @@ bool PythonImport::preprocess(QString& line) {
     return false;  // The input was not completely consumed by preprocessing.
 }
 
-void PythonImport::fillSource(QString word) {
+void PythonImport::fillSource(const QString& word) {
     QString lexeme;
     const uint len = word.length();
     for (uint i = 0; i < len; i++) {
@@ -101,7 +101,7 @@ void PythonImport::fillSource(QString word) {
             if (!lexeme.isEmpty()) {
                 m_source.append(lexeme);
                 m_srcIndex++;
-                lexeme = QString::null;
+                lexeme = QString();
             }
             m_source.append(QString(c));
             m_srcIndex++;
@@ -118,7 +118,7 @@ void PythonImport::skipBody() {
         skipStmt("{");
     int braceNesting = 0;
     QString token;
-    while ((token = advance()) != QString::null) {
+    while (!(token = advance()).isNull()) {
         if (token == "}") {
             if (braceNesting <= 0)
                 break;
@@ -137,7 +137,7 @@ bool PythonImport::parseStmt() {
         UMLObject *ns = Import_Utils::createUMLObject(Uml::ot_Class,
                         name, m_scope[m_scopeIndex], m_comment);
         m_scope[++m_scopeIndex] = m_klass = static_cast<UMLClassifier*>(ns);
-        m_comment = QString::null;
+        m_comment = QString();
         if (advance() == "(") {
             while (m_srcIndex < srcLength - 1 && advance() != ")") {
                 const QString& baseName = m_source[m_srcIndex];
@@ -161,7 +161,7 @@ bool PythonImport::parseStmt() {
         // operation
         UMLOperation *op = Import_Utils::makeOperation(m_klass, name);
         if (advance() != "(") {
-            kdError() << "importPython def " << name << ": expecting \"(\"" << endl;
+            kError() << "importPython def " << name << ": expecting \"(\"" << endl;
             skipBody();
             return true;
         }
@@ -181,7 +181,7 @@ bool PythonImport::parseStmt() {
         if (m_scopeIndex)
             m_klass = dynamic_cast<UMLClassifier*>(m_scope[--m_scopeIndex]);
         else
-            kdError() << "importPython: too many }" << endl;
+            kError() << "importPython: too many }" << endl;
         return true;
     }
     return false;  // @todo parsing of attributes
