@@ -11,8 +11,13 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2004-2007                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
+// own header
+#include "configurable.h"
+
 // Qt includes
 #include <qstringlist.h>
 
@@ -21,7 +26,6 @@
 #include <kconfig.h>
 
 // local includes
-#include "configurable.h"
 #include "pluginloader.h"
 #include "plugin.h"
 
@@ -29,49 +33,49 @@ using namespace Umbrello;
 
 
 Configurable::Configurable() :
-  _plugins()
+        _plugins()
 {
-  _plugins.setAutoDelete(FALSE);
+    _plugins.setAutoDelete(false);
 }
 
 Configurable::~Configurable()
 {
-  unloadPlugins();
+    unloadPlugins();
 }
 
 bool
 Configurable::loadPlugins(KConfig *config,
-			  const QString &key)
+                          const QString &key)
 {
-  bool ret = true;
+    bool ret = true;
 
-  QStringList names = config->readListEntry(key);
-  for(uint i = 0; i != names.size(); i++) {
-    const QString &name = names[i];
+    QStringList names = config->readListEntry(key);
+    for(uint i = 0; i != names.size(); i++) {
+        const QString &name = names[i];
 
-    kdDebug() << "loading plugin " << name << endl;
+        kdDebug() << "loading plugin " << name << endl;
 
-    // load the plugin
-    Plugin *plugin = PluginLoader::instance()->loadPlugin(name);
+        // load the plugin
+        Plugin *plugin = PluginLoader::instance()->loadPlugin(name);
 
-    // keep the plugin
-    if(plugin) {
-      _plugins.append(plugin);
+        // keep the plugin
+        if(plugin) {
+            _plugins.append(plugin);
+        }
     }
-  }
 
-  return ret;
+    return ret;
 }
 
 bool
 Configurable::unloadPlugins()
 {
-  // just iterate through and dereference all the
-  // plugins.
-  for(uint i = 0; i != _plugins.count(); i++) {
-    Plugin *plugin = _plugins.at(i);
-    plugin->unload();
-  }
-  _plugins.clear();
-  return true;
+    // just iterate through and dereference all the
+    // plugins.
+    for(uint i = 0; i != _plugins.count(); i++) {
+        Plugin *plugin = _plugins.at(i);
+        plugin->unload();
+    }
+    _plugins.clear();
+    return true;
 }
