@@ -5,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2006-2007                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef EXPORTALLVIEWSDIALOG_H
@@ -41,7 +43,7 @@ public:
      *
      * @see QDialog::QDialog
      */
-    ExportAllViewsDialog(QWidget* parent = 0, const char* name = 0,
+    explicit ExportAllViewsDialog(QWidget* parent = 0, const char* name = 0,
                          bool modal = false, WFlags fl = 0,
                          const QString& defaultMimeType = "image/png");
 
