@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2002-2005
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2002-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -30,6 +27,9 @@
 #include "../umldoc.h"
 #include "../dialog_utils.h"
 #include "../object_factory.h"
+#include "../stereotype.h"
+
+#include "parmpropdlg.moc"
 
 ParmPropDlg::ParmPropDlg(QWidget * parent, UMLDoc * doc, UMLAttribute * a)
         : KDialogBase(Plain, i18n("Parameter Properties"), Help | Ok | Cancel , Ok, parent, "_PARMPROPDLG_", true, true)
@@ -74,9 +74,10 @@ ParmPropDlg::ParmPropDlg(QWidget * parent, UMLDoc * doc, UMLAttribute * a)
                                     m_pInitialL, i18n("&Initial value:"),
                                     m_pInitialLE, initialValue );
 
-    Dialog_Utils::makeLabeledEditField( m_pParmGB, propLayout, 3,
-                                    m_pStereoTypeL, i18n("&Stereotype name:"),
-                                    m_pStereoTypeLE, m_pAtt->getStereotype() );
+    m_pStereoTypeL = new QLabel( i18n("Stereotype name:"), m_pParmGB );
+    propLayout -> addWidget(m_pStereoTypeL, 3, 0);
+    m_pStereoTypeCB = new KComboBox(true, m_pParmGB );
+    propLayout -> addWidget(m_pStereoTypeCB, 3, 1);
 
     m_pKind =  new QButtonGroup(i18n("Passing Direction"), plainPage());
     m_pKind->setExclusive(true);
@@ -128,7 +129,7 @@ ParmPropDlg::ParmPropDlg(QWidget * parent, UMLDoc * doc, UMLAttribute * a)
     //add template parameters
     UMLClassifier *pConcept = dynamic_cast<UMLClassifier*>( m_pAtt->parent()->parent() );
     if (pConcept == NULL) {
-        kdError() << "ParmPropDlg: grandparent of " << m_pAtt->getName()
+        kError() << "ParmPropDlg: grandparent of " << m_pAtt->getName()
         << " is not a UMLClassifier" << endl;
     } else {
         UMLTemplateList tmplParams( pConcept->getTemplateList() );
@@ -160,12 +161,33 @@ ParmPropDlg::ParmPropDlg(QWidget * parent, UMLDoc * doc, UMLAttribute * a)
         m_pTypeCB->setCurrentItem(0);
     }
 
+    // manage stereotypes
+    m_pStereoTypeCB->setDuplicatesEnabled(false); //only allow one of each type in box
+    m_pStereoTypeCB->setCompletionMode( KGlobalSettings::CompletionPopup );
+    insertStereotype (QString("")); // an empty stereotype is the default
+    int defaultStereotype=0;
+    bool foundDefaultStereotype = false;
+    for (UMLStereotypeListIt it(m_pUmldoc->getStereotypes()); it.current(); ++it) {
+        if (!foundDefaultStereotype) {
+            if ( m_pAtt->getStereotype() == it.current()->getName()) {
+                foundDefaultStereotype = true;
+            }
+            defaultStereotype++;
+        }
+        insertStereotype (it.current()->getName());
+    }
+    // lookup for a default stereotype, if the operation doesn't have one
+    if (foundDefaultStereotype)
+        m_pStereoTypeCB->setCurrentItem(defaultStereotype);
+    else
+        m_pStereoTypeCB->setCurrentItem(-1);
+
     // set tab order
     setTabOrder(m_pKind, m_pTypeCB);
     setTabOrder(m_pTypeCB, m_pNameLE);
     setTabOrder(m_pNameLE, m_pInitialLE);
-    setTabOrder(m_pInitialLE, m_pStereoTypeLE);
-    setTabOrder(m_pStereoTypeLE, m_pIn);
+    setTabOrder(m_pInitialLE, m_pStereoTypeCB);
+    setTabOrder(m_pStereoTypeCB, m_pIn);
     setTabOrder(m_pIn, m_pDoc);
 
     m_pNameLE->setFocus();
@@ -177,6 +199,12 @@ void ParmPropDlg::insertType( const QString& type, int index )
     m_pTypeCB->completionObject()->addItem( type );
 }
 
+void ParmPropDlg::insertStereotype( const QString& type, int index )
+{
+    m_pStereoTypeCB->insertItem( type, index );
+    m_pStereoTypeCB->completionObject()->addItem( type );
+}
+
 Uml::Parameter_Direction ParmPropDlg::getParmKind() {
     Uml::Parameter_Direction pk = Uml::pd_In;
     if (m_pOut->isChecked())
@@ -189,11 +217,11 @@ Uml::Parameter_Direction ParmPropDlg::getParmKind() {
 void ParmPropDlg::slotOk() {
     if (m_pAtt != NULL) {
         m_pAtt->setParmKind( getParmKind() );
-        m_pAtt->setStereotype( m_pStereoTypeLE->text() );
+        m_pAtt->setStereotype( m_pStereoTypeCB->currentText() );
         QString typeName = m_pTypeCB->currentText();
         UMLClassifier * pConcept = dynamic_cast<UMLClassifier*>( m_pAtt->parent()->parent() );
         if (pConcept == NULL) {
-            kdError() << "ParmPropDlg::slotOk: grandparent of " << m_pAtt->getName()
+            kError() << "ParmPropDlg::slotOk: grandparent of " << m_pAtt->getName()
             << " is not a UMLClassifier" << endl;
         } else {
             UMLTemplate *tmplParam = pConcept->findTemplate(typeName);
@@ -215,7 +243,7 @@ void ParmPropDlg::slotOk() {
             // Nothing found: Create a new type on the fly.
             // @todo There should be an extra dialog to decide whether to
             // create a datatype or a class. For now, we create a class.
-            kdDebug() << "ParmPropDlg::slotOk: " << typeName << " not found."
+            kDebug() << "ParmPropDlg::slotOk: " << typeName << " not found."
                 << " Creating a new class for the type." << endl;
             UMLObject *o = Object_Factory::createUMLObject(Uml::ot_Class, typeName);
             m_pAtt->setType(o);
