@@ -179,21 +179,26 @@ void FloatingTextWidget::handleRename() {
                                             m_pView, NULL, &v);
     if (!ok || newText == getText())
         return;
+}
+
+void FloatingTextWidget::changeName(const QString& newText)
+{
+
     if (m_pLink && !isTextValid(newText)) {
         AssociationWidget *assoc = dynamic_cast<AssociationWidget*>(m_pLink);
         if (assoc) {
             switch (m_Role) {
               case Uml::tr_MultiA:
-                assoc->setMulti(QString::null, Uml::A);
+                assoc->setMulti(QString(), Uml::A);
                 break;
               case Uml::tr_MultiB:
-                assoc->setMulti(QString::null, Uml::B);
+                assoc->setMulti(QString(), Uml::B);
                 break;
               case Uml::tr_RoleAName:
-                assoc->setRoleName(QString::null, Uml::A);
+                assoc->setRoleName(QString(), Uml::A);
                 break;
               case Uml::tr_RoleBName:
-                assoc->setRoleName(QString::null, Uml::B);
+                assoc->setRoleName(QString(), Uml::B);
                 break;
               case Uml::tr_ChangeA:
                 assoc->setChangeability(Uml::chg_Changeable, Uml::A);
@@ -202,13 +207,13 @@ void FloatingTextWidget::handleRename() {
                 assoc->setChangeability(Uml::chg_Changeable, Uml::B);
                 break;
               default:
-                assoc->setName(QString::null);
+                assoc->setName(QString());
                 break;
             }
         } else {
             MessageWidget *msg = dynamic_cast<MessageWidget*>(m_pLink);
             if (msg) {
-                msg->setName(QString::null);
+                msg->setName(QString());
                 m_pView->removeWidget(this);
             }
         }
@@ -315,7 +320,7 @@ void FloatingTextWidget::showOpDlg() {
             if (od.m_pReturnType)
                 op->setType(od.m_pReturnType);
             m_pLink->setOperation(op);
-            opText = QString::null;
+            opText = QString();
         } else {
             m_pLink->setOperation(NULL);
         }
