@@ -5,10 +5,14 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2006                                               *
+ *   copyright (C) 2002-2007                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
+// own header
+#include "linepath.h"
+
+// system includes
 #include <cstdlib>
 #include <cmath>
 
@@ -27,7 +31,6 @@
 #include "umlview.h"
 #include "umldoc.h"
 #include "uml.h"
-#include "linepath.h"
 
 LinePath::Circle::Circle(QCanvas * canvas, int radius /* = 0 */)
         : QCanvasEllipse(radius * 2, radius * 2, canvas) {
@@ -68,6 +71,7 @@ LinePath::LinePath() {
     m_pAssociation = 0;
     m_bHeadCreated = false;
     m_bParallelLineCreated = false;
+    m_DockRegion = TopBottom;
 }
 
 LinePath::~LinePath() {}
@@ -102,6 +106,10 @@ bool LinePath::setPoint( int pointIndex, const QPoint &point ) {
     int count = m_LineList.count();
     if( count == 0 || pointIndex > count  || pointIndex < 0)
         return false;
+    if (point.x() == 0 && point.y() == 0) {
+        kError() << "LinePath::setPoint:ignoring request for (0,0)" << endl;
+        return false;
+    }
 
     if( pointIndex == count) {
         QCanvasLine * line = m_LineList.last();
