@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2002-2004
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2002-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef LINEPATH_H
@@ -205,7 +202,7 @@ protected:
      */
     class Circle : public QCanvasEllipse {
     public:
-        Circle(QCanvas * canvas, int radius = 0);
+        explicit Circle(QCanvas * canvas, int radius = 0);
         void setRadius(int radius);
         int getRadius() const;
         void setX(int x);
@@ -274,7 +271,8 @@ protected:
     /**
      * Create a number of new lines and append them to the given list.
      *
-     * @param by  The number of lines to insert into the given list.
+     * @param list  The list into which to append lines.
+     * @param by    The number of lines to insert into the given list.
      */
     void growList(LineList &list, int by);
 
