@@ -5,16 +5,18 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006                                                    *
+ *   copyright (C) 2006-2007                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
+// own header
+#include "messagewidgetcontroller.h"
+
 // kde includes
 #include <kcursor.h>
 #include <kdebug.h>
 
 // app includes
-#include "messagewidgetcontroller.h"
 #include "messagewidget.h"
 #include "floatingtextwidget.h"
 #include "objectwidget.h"
@@ -23,6 +25,7 @@
 MessageWidgetController::MessageWidgetController(MessageWidget* messageWidget):
             UMLWidgetController(messageWidget) {
     m_messageWidget = messageWidget;
+    m_unconstrainedPositionY = 0;
 }
 
 MessageWidgetController::~MessageWidgetController() {
