@@ -6,7 +6,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2002-2006                                               *
- *   Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                 *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -34,6 +34,7 @@ NoteWidget::NoteWidget(UMLView * view, Uml::IDType id)
         : UMLWidget(view, id, new NoteWidgetController(this)) {
     init();
     setSize(100,80);
+    setZ( 20 ); //make sure always on top.
 #ifdef NOTEWIDGET_EMBED_EDITOR
     // NB: This code is currently deactivated because
     // Zoom does not yet work with the embedded text editor.
@@ -64,7 +65,7 @@ void NoteWidget::setDiagramLink(Uml::IDType viewID) {
     UMLDoc *umldoc = UMLApp::app()->getDocument();
     UMLView *view = umldoc->findView(viewID);
     if (view == NULL) {
-        kdError() << "NoteWidget::setDiagramLink(" << ID2STR(viewID)
+        kError() << "NoteWidget::setDiagramLink(" << ID2STR(viewID)
         << "): no view found for this ID." << endl;
         return;
     }
@@ -235,11 +236,11 @@ void NoteWidget::drawText(QPainter * p /*=NULL*/, int offsetX /*=0*/, int offset
         } else {
             // all chars of text have been handled already ->
             // perform this last run to spool current content of "word"
-            c = returnChar; 
+            c = returnChar;
         }
         if (c == returnChar || c.isSpace()) {
             // new word delimiter found -> its time to decide on word wrap
-            testCombineLine = fullLine + " " + word;
+            testCombineLine = fullLine + ' ' + word;
             int textWidth = fm.width( testCombineLine );
             if (textX + textWidth > width) {
                 // combination of "fullLine" and "word" doesn't fit into one line ->
@@ -302,6 +303,7 @@ void NoteWidget::saveToXMI( QDomDocument & qDoc, QDomElement & qElement ) {
 bool NoteWidget::loadFromXMI( QDomElement & qElement ) {
     if( !UMLWidget::loadFromXMI( qElement ) )
         return false;
+    setZ( 20 ); //make sure always on top.
     setDoc( qElement.attribute("text", "") );
     QString diagramlink = qElement.attribute("diagramlink", "");
     if (!diagramlink.isEmpty())
