@@ -1,8 +1,3 @@
-/***************************************************************************
-                          refactoringassistant.h
-                             -------------------
-    copyright            : (C) 2003 Luis De la Parra
- ***************************************************************************/
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2003 Luis De la Parra <lparrab@gmx.net>                 *
  *   copyright (C) 2004-2007                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
@@ -38,7 +34,7 @@ class RefactoringAssistant : public KListView
 public:
     typedef std::map<QListViewItem*, UMLObject*> UMLObjectMap;
 
-    RefactoringAssistant( UMLDoc *doc, UMLClassifier *obj = 0, QWidget *parent = 0, const char *name = 0 );
+    explicit RefactoringAssistant( UMLDoc *doc, UMLClassifier *obj = 0, QWidget *parent = 0, const char *name = 0 );
     virtual ~RefactoringAssistant();
 
     void refactor( UMLClassifier *obj );
