@@ -5,12 +5,20 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2006                                               *
+ *   copyright (C) 2003-2007                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
+
+// own header
+#include "umlcanvasobject.h"
+
+// qt/kde includes
+#include <kdebug.h>
+#include <klocale.h>
+
+// local includes
 #include "uml.h"
 #include "umldoc.h"
-#include "umlcanvasobject.h"
 #include "classifier.h"
 #include "association.h"
 #include "attribute.h"
@@ -18,8 +26,6 @@
 #include "template.h"
 #include "stereotype.h"
 #include "clipboard/idchangelog.h"
-#include <kdebug.h>
-#include <klocale.h>
 
 UMLCanvasObject::UMLCanvasObject(const QString & name, Uml::IDType id)
         : UMLObject(name, id)
@@ -66,11 +72,8 @@ bool UMLCanvasObject::addAssociationEnd(UMLAssociation* assoc) {
         m_List.append( assoc );
 
         // Don't emit signals during load from XMI
-        UMLDoc *umldoc = UMLApp::app()->getDocument();
-        if (! umldoc->loading()) {
-            emit modified();
-            emit sigAssociationEndAdded(assoc);
-        }
+        UMLObject::emitModified();
+        emit sigAssociationEndAdded(assoc);
         return true;
     }
     return false;
@@ -88,7 +91,7 @@ int UMLCanvasObject::removeAssociationEnd(UMLAssociation * assoc) {
             << "can't find given assoc in list" << endl;
         return -1;
     }
-    emit modified();
+    UMLObject::emitModified();
     emit sigAssociationEndRemoved(assoc);
     return m_List.count();
 }
@@ -136,25 +139,32 @@ void UMLCanvasObject::removeAllChildObjects() {
 }
 
 QString UMLCanvasObject::uniqChildName( const Uml::Object_Type type,
-                                        bool seekStereo /* = false */ ) {
-    QString currentName;
-    if (seekStereo) {
-        currentName = i18n("new_stereotype");
-    } else if (type == Uml::ot_Association) {
-        currentName = i18n("new_association");
-    } else if (type == Uml::ot_Attribute) {
-        currentName = i18n("new_attribute");
-    } else if (type == Uml::ot_Template) {
-        currentName = i18n("new_template");
-    } else if (type == Uml::ot_Operation) {
-        currentName = i18n("new_operation");
-    } else if (type == Uml::ot_EnumLiteral) {
-        currentName = i18n("new_literal");
-    } else if (type == Uml::ot_EntityAttribute) {
-        currentName = i18n("new_field");
-    } else {
-        kWarning() << "uniqChildName() called for unknown child type " << type << endl;
-        return "ERROR_in_UMLCanvasObject_uniqChildName";
+                                        const QString &prefix /* = QString() */ ) {
+    QString currentName = prefix;
+    if (currentName.isEmpty()) {
+        switch (type) {
+            case Uml::ot_Association:
+                currentName = i18n("new_association");
+                break;
+            case Uml::ot_Attribute:
+                currentName = i18n("new_attribute");
+                break;
+            case Uml::ot_Template:
+                currentName = i18n("new_template");
+                break;
+            case Uml::ot_Operation:
+                currentName = i18n("new_operation");
+                break;
+            case Uml::ot_EnumLiteral:
+                currentName = i18n("new_literal");
+                break;
+            case Uml::ot_EntityAttribute:
+                currentName = i18n("new_field");
+                break;
+            default:
+                kWarning() << "uniqChildName() called for unknown child type " << type << endl;
+                return "ERROR_in_UMLCanvasObject_uniqChildName";
+        }
     }
 
     QString name = currentName;
