@@ -17,7 +17,6 @@
 #include "umlclassifierlist.h"
 #include "umlassociationlist.h"
 
-class IDChangeLog;
 
 /**
  * This class contains the non-graphical information required for UMLObjects
@@ -43,7 +42,7 @@ public:
      * @param name              The name of the Concept.
      * @param id                The unique id of the Concept.
      */
-    UMLCanvasObject(const QString & name = "", Uml::IDType id = Uml::id_None);
+    explicit UMLCanvasObject(const QString & name = "", Uml::IDType id = Uml::id_None);
 
     /**
      * Standard deconstructor.
@@ -82,7 +81,7 @@ public:
     /**
      * Remove an association end from the CanvasObject.
      *
-     * @param o         The association to remove.
+     * @param assoc         The association to remove.
      *                  @todo change param type to UMLRole
      */
     int removeAssociationEnd(UMLAssociation *assoc);
@@ -175,6 +174,7 @@ public:
      * Find an association.
      *
      * @param id        The id of the object to find.
+     * @param considerAncestors boolean switch to consider ancestors while searching
      * @return  Pointer to the object found (NULL if not found.)
      */
     virtual UMLObject *findChildObjectById(Uml::IDType id, bool considerAncestors = false);
