@@ -19,7 +19,7 @@
 #ifndef UMLLISTVIEWITEMLIST_H
 #define UMLLISTVIEWITEMLIST_H
 
-//#include "umllistviewitem.h"
+#include <qptrlist.h>
 
 class UMLListViewItem;
 
