@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2006                                               *
+ *   copyright (C) 2002-2007                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -50,6 +50,7 @@ public:
      *
      * @param view The view to be displayed on.
      * @param o The UMLObject to represent.
+     * @param widgetController The UMLWidgetController of this UMLWidget
      */
     UMLWidget( UMLView * view, UMLObject * o, UMLWidgetController *widgetController = 0 );
 
@@ -59,8 +60,9 @@ public:
      * @param view The view to be displayed on.
      * @param id The id of the widget.
      *  The default value (id_None) will prompt generation of a new ID.
+     * @param widgetController The UMLWidgetController of this UMLWidget
      */
-    UMLWidget( UMLView * view, Uml::IDType id = Uml::id_None, UMLWidgetController *widgetController = 0 );
+    explicit UMLWidget( UMLView * view, Uml::IDType id = Uml::id_None, UMLWidgetController *widgetController = 0 );
 
     /**
      * Standard deconstructor
@@ -82,16 +84,6 @@ public:
      */
     virtual bool operator==(const UMLWidget& other);
 
-    /**
-    * Write property of m_nId.
-    */
-    void setID( Uml::IDType id );
-
-    /**
-    * Read property of m_nId.
-    */
-    Uml::IDType getID() const;
-
     /**
      * Calls the method with the same name in UMLWidgetController.
      * @see UMLWidgetController#mouseReleaseEvent
@@ -195,8 +187,9 @@ public:
      * Activate the object after serializing it from a QDataStream
      *
      * @param ChangeLog
+     * @return  true for success
      */
-    virtual void activate(IDChangeLog* ChangeLog = 0);
+    virtual bool activate(IDChangeLog* ChangeLog = 0);
 
     /**
      * Returns 0 if the given point is not in the boundaries of the widget,
@@ -414,16 +407,14 @@ public:
     /**
      * Set the status of whether to show Stereotype.
      *
-     * @param _show             True if stereotype shall be shown.
+     * @param _status             True if stereotype shall be shown.
      */
     virtual void setShowStereotype(bool _status);
 
     /**
      * Show a properties dialog for a UMLWidget.
-     *
-     * @return  True if the widget was modified.
      */
-    bool showProperties();
+    virtual void showProperties();
 
     /**
      * Returns true if the Activate method has been called for this instance
@@ -516,7 +507,7 @@ public:
      *
      * @param me The move event.
      */
-    virtual void moveEvent(QMoveEvent *) { }
+    virtual void moveEvent(QMoveEvent *me);
 
     virtual void saveToXMI( QDomDocument & qDoc, QDomElement & qElement );
 
@@ -594,13 +585,6 @@ protected:
 
     ///////////////// Data Loaded/Saved /////////////////////////////////
 
-    /**
-     * This ID is only used when the UMLWidget does not have a
-     * corresponding UMLObject (i.e. the m_pObject pointer is NULL.)
-     * For UML objects, the ID from the UMLObject is used.
-     */
-    Uml::IDType m_nId;
-
     /**
      * This flag indicates if the UMLWidget uses the Diagram FillColour
      */
@@ -646,7 +630,7 @@ protected:
     QString m_instanceName;
 
     /**
-     * Should it show the <<stereotype>> of the widget
+     * Should the stereotype be displayed
      */
     bool m_bShowStereotype;
 
@@ -689,8 +673,6 @@ public slots:
 
     /**
      * When a widget changes this slot captures that signal.
-     *
-     * @param o The changed UMLobject
      */
     virtual void updateWidget();
 
