@@ -57,7 +57,7 @@ class UMLWidget;
  * current position of the widgets and the new position to be moved to. For
  * example, if a widget shouldn't be moved in X axis, it's receiving the
  * mouseMoveEvents and there are other widgets selected, those other widgets
- * shouldn't be allowed neither to be moved in X axis.
+ * shouldn't be allowed either to be moved in X axis.
  *
  * The behaviour when double clicking on the widget after it's selected can be
  * customized with doMouseDoubleClick.
@@ -361,11 +361,22 @@ protected:
      */
     int getBiggestY(const UMLWidgetList &widgetList);
 
+    /**
+     * Returns the adjusted position for the given mouse event.
+     * The adjusted position is computed using the current widget position
+     * m_widget->get{X,Y}(), the previous position m_old{X,Y}, and the
+     * mouse press offset m_pressOffset{X,Y}.
+     *
+     * @param me The QMouseEvent for which to get the adjusted position.
+     * @return A QPoint with the adjusted position.
+     */
+    QPoint getPosition(QMouseEvent *me);
+
     /**
      * Returns a QPoint with the new X and Y position difference of the mouse event
      * respect to the position of the widget.
      *
-     * @param me The QMouseEVent to get the position to compare.
+     * @param me The QMouseEvent to get the position to compare.
      * @return A QPoint with the position difference.
      */
     QPoint getPositionDifference(QMouseEvent *me);
